@@ -15,10 +15,15 @@ Module giving easy access to PushBullet API
     
     $pb->push_address({ device_id => $device_id, name => $name, 
         address => $address });
+        
+    $pb->push_file({ device_id => $device_id, file => $filename);
+        
     $pb->push_link({ device_id => $device_id, title => $title,
         url => $url });
+        
     $pb->push_list({ device_id => $device_id, title => $title, 
         items => \@items });
+        
     $pb->push_note({ device_id => $device_id, title => $title,
         body => $body });
 
@@ -29,10 +34,12 @@ package WWW::PushBullet;
 use strict;
 use warnings;
 
+use Data::Dump qw(dump);
 use JSON;
 use LWP::UserAgent;
+use LWP::Protocol::https;
 
-our $VERSION = '0.8';
+our $VERSION = '0.9';
 
 my %PUSHBULLET = (
     REALM   => 'Pushbullet',
@@ -48,20 +55,24 @@ $ENV{PERL_LWP_SSL_VERIFY_HOSTNAME} = 0;
 
 Creates a new instance of PushBullet API
 
+    my $pb = WWW::PushBullet->new({apikey => $apikey});
+
 =cut
 
 sub new
 {
     my ($class, $params) = @_;
 
+    return (undef) if (!defined $params->{apikey});
     my $ua = LWP::UserAgent->new;
     $ua->agent("WWW::PushBullet/$VERSION");
     $ua->credentials($PUSHBULLET{SERVER}, $PUSHBULLET{REALM}, $params->{apikey},
         '');
-    #$ua->proxy('https', 'http://localhost:8080/');
+
     my $self = {
         _ua     => $ua,
         _apikey => $params->{apikey},
+        _debug  => $params->{debug} || 0,
     };
 
     bless $self, $class;
@@ -69,10 +80,27 @@ sub new
     return ($self);
 }
 
+=head2 DEBUG
+
+Prints Debug message when '_debug' is enabled
+
+=cut
+
+sub DEBUG
+{
+    my ($self, $line) = @_;
+
+    printf "[DEBUG] %s\n", $line if ($self->{_debug});
+
+    return ($line);
+}
+
 =head2 api_key()
 
 Returns current PushBullet API key
 
+    my $apikey = $pb->api_key();
+
 =cut
 
 sub api_key
@@ -82,10 +110,34 @@ sub api_key
     return ($self->{_apikey});
 }
 
-=head2 devices()
+=head2 debug_mode
 
+Sets Debug mode
+
+    $pb->debug_mode(1);
+    
+=cut
+
+sub debug_mode
+{
+    my ($self, $mode) = shift;
+
+    $self->{_debug} = $mode;
+
+    return ($self->{_debug});
+}
+
+=head2 devices()
+    
 Returns list of devices
 
+    my $devices = $pb->devices();
+    
+    foreach my $d (@{$devices})
+    {
+        printf "Device '%s' => id %s\n", $d->{extras}->{model}, $d->{id};
+    }
+
 =cut
 
 sub devices
@@ -106,24 +158,26 @@ sub devices
     }
 }
 
-=head2 pushes($content)
+=head2 _pushes($content)
 
-Generic pushes function
+Generic pushes function (not supposed to be used directly)
 
 =cut
 
-sub pushes
+sub _pushes
 {
     my ($self, $content) = @_;
 
     my $type = undef;
-    foreach my $i (0..$#{$content})
+    foreach my $i (0 .. $#{$content})
     {
-        $type = $content->[$i+1] if ($content->[$i] eq 'type'); 
+        $type = $content->[$i + 1] if ($content->[$i] eq 'type');
     }
-    my $res = $self->{_ua}->post("$PUSHBULLET{URL_API}/pushes", 
+    my $res = $self->{_ua}->post(
+        "$PUSHBULLET{URL_API}/pushes",
         Content_Type => ($type eq 'file' ? 'form-data' : undef),
-        Content => $content);
+        Content => $content
+    );
 
     if ($res->is_success)
     {
@@ -141,19 +195,28 @@ sub pushes
 
 Pushes address (with name & address)
 
+    $pb->push_address(
+        {
+            device_id => $device_id,
+            name      => 'GooglePlex',
+            address   => '1600 Amphitheatre Pkwy, Mountain View, CA 94043, Etats-Unis'
+        }
+        );
+
 =cut
 
 sub push_address
 {
     my ($self, $params) = @_;
 
-    my $content = [ 
-        type => 'address',
+    my $content = [
+        type      => 'address',
         device_id => $params->{device_id},
-        name => $params->{name},
-        address => $params->{address},
-        ];
-    my $result = $self->pushes($content);
+        name      => $params->{name},
+        address   => $params->{address},
+    ];
+    $self->DEBUG(sprintf('push_address: %s', dump($content)));
+    my $result = $self->_pushes($content);
 
     return ($result);
 }
@@ -162,6 +225,8 @@ sub push_address
 
 Pushes file
 
+    $pb->push_file({ device_id => $device_id, file => '/var/www/index.html' });
+
 =cut
 
 sub push_file
@@ -169,12 +234,13 @@ sub push_file
     my ($self, $params) = @_;
 
     my $content = [
-        type => 'file',
+        type      => 'file',
         device_id => $params->{device_id},
-        file => [ $params->{file} ],
-        ];
-    my $result = $self->pushes($content);
-    
+        file      => [$params->{file}],
+    ];
+    $self->DEBUG(sprintf('push_file: %s', dump($content)));
+    my $result = $self->_pushes($content);
+
     return ($result);
 }
 
@@ -182,27 +248,43 @@ sub push_file
 
 Pushes link (with title & url)
 
+    $pb->push_link(
+        {
+            device_id => $device_id,
+            title     => 'WWW::PushBullet Perl module on GitHub',
+            url       => 'https://github.com/sebthebert/WWW-PushBullet'
+        }
+        );
+
 =cut
 
 sub push_link
 {
     my ($self, $params) = @_;
 
-    my $content = [ 
-        type => 'link',
+    my $content = [
+        type      => 'link',
         device_id => $params->{device_id},
-        title => $params->{title},
-        url => $params->{url},
-        ];
-        
-    my $result = $self->pushes($content);
+        title     => $params->{title},
+        url       => $params->{url},
+    ];
+    $self->DEBUG(sprintf('push_link: %s', dump($content)));
+    my $result = $self->_pushes($content);
 
     return ($result);
 }
 
 =head2 push_list($params)
 
-Pushes link (with title & items)
+Pushes list (with title & items)
+
+    $pb->push_list(
+        {
+            device_id => $device_id,
+            title     => 'One list with 3 items',
+            items     => [ 'One', 'Two', 'Three' ]
+        }
+        );
 
 =cut
 
@@ -211,12 +293,13 @@ sub push_list
     my ($self, $params) = @_;
 
     my $content = [
-        type => 'list',
+        type      => 'list',
         device_id => $params->{device_id},
-        title => $params->{title}, 
-        items => $params->{items},
-        ];
-    my $result = $self->pushes($content);
+        title     => $params->{title},
+        items     => $params->{items},
+    ];
+    $self->DEBUG(sprintf('push_list: %s', dump($content)));
+    my $result = $self->_pushes($content);
 
     return ($result);
 }
@@ -225,6 +308,14 @@ sub push_list
 
 Pushes note (with title & body)
 
+    $pb->push_note(
+        {
+            device_id => $device_id,
+            title     => 'Note Title',
+            body      => 'Note Body'
+        }
+        );
+
 =cut
 
 sub push_note
@@ -232,16 +323,28 @@ sub push_note
     my ($self, $params) = @_;
 
     my $content = [
-        type => 'note',
+        type      => 'note',
         device_id => $params->{device_id},
-        title => $params->{title}, 
-        body => $params->{body},
-        ];
-    my $result = $self->pushes($content);
+        title     => $params->{title},
+        body      => $params->{body},
+    ];
+    $self->DEBUG(sprintf('push_note: %s', dump($content)));
+    my $result = $self->_pushes($content);
 
     return ($result);
 }
 
+=head2 version()
+
+Returns WWW::PushBullet module version
+
+=cut
+
+sub version
+{
+    return ($VERSION);
+}
+
 1;
 
 =head1 AUTHOR
